import os

from flask import request, send_file, after_this_request, Blueprint
from flask_restplus import Namespace, fields, Resource
from pyrest.utils.timelapse.Timelapse import TimelapseFactory



timelapse_api = Namespace('timelapse', description='Operations for creating timelapses')
supported_apps = ['terrascope',  'probav']

from pyrest.models.timelapse import timelapse_model


# Base timelapse service
@timelapse_api.route('/')
class TimelapseBaseService(Resource):
    def get(self):
        return "<h1>Welcome to the timelapse API</h1>"


# Timelapse creation service
@timelapse_api.route("/<type>")
@timelapse_api.param('type', 'Format of the timelapse to create')
class TimelapseCreationServie(Resource):
    @timelapse_api.expect(timelapse_model)
    @timelapse_api.doc('Create a timelapse based on the type specified in the url parameter')
    def post(self, type):
        data = request.json
        timelapse = TimelapseFactory.factory(type.upper())

        if not "language" in data["settings"]:
            language = "en"
        else:
            language = data["settings"]["language"].lower()

        for image in data["images"]:
            timelapse.addWMSImage(url=image['url'], text=image['text'], application=data["settings"]["application"], language=language)

        if not "application" in  data["settings"]:
            return 'Please specify an application. Supported Applications: ' + ','.join(supported_apps), 400


        if not data["settings"]["application"] in supported_apps:
            return 'Application %s is not supported. Supported Applications: %s' % (data["settings"]["application"], ','.join(supported_apps)), 400

        file_path = timelapse.create(application=data["settings"]["application"], language=language, delay=data["settings"]["delay"], loop=0 if data["settings"]["loop"] else 1)

        @after_this_request
        def remove_file(response):
            # parent_dir = os.path.abspath(os.path.join(file_path, os.pardir))
            # for root, dir, files in os.walk(parent_dir):
            #     for file in files:
            #         os.remove(root + '/' + file)
            # os.rmdir(parent_dir)
            return response
        return send_file(file_path, 'image/gif')
